@@ -129,6 +129,19 @@ def ignore_wip(reviews):
     return [x for x in reviews if x['status'] != 'WORKINPROGRESS']
 
 
+def which(program):
+    """Locates a program file in the user's path."""
+    for path in os.environ['PATH'].split(":"):
+        if os.path.exists(path + '/' + program):
+            return path + '/' + program
+
+
+def open_url(url):
+    """Opens a URL using whatever program is available on the system."""
+    open_app = which('xdg-open') or 'open'
+    os.system('%s %s' % (open_app, url))
+
+
 def main(args):
     client = ssh_client(
         host=args.host, port=args.port, user=args.username, key=args.key)
@@ -158,7 +171,7 @@ def main(args):
         render_reviews(reviews, maximum=1)
 
         # open the oldest code review in a browser
-        os.system('open %s' % reviews[0]['url'])
+        open_url(reviews[0]['url'])
 
     sys.exit(len(reviews))
 
@@ -174,7 +187,7 @@ def cli():
         '--port', type=int, default=DEFAULT_GERRIT_PORT,
         help='SSH port for gerrit')
     parser.add_argument(
-        '--username', default=os.getlogin(),
+        '-u', '--username', default=os.getlogin(),
         help='Your SSH username for gerrit')
     parser.add_argument(
         '--email', default=None,
